import rclpy
from rclpy.node import Node,Parameter
from rcl_interfaces.srv import SetParametersAtomically

class HapticClient(Node):
    def __init__(self):
        super().__init__('haptic_client')
        self.cli_info = self.create_client(SetParametersAtomically, '/camera_node/set_parameters_atomically')
        while not self.cli_info.wait_for_service(timeout_sec=1.0):
            self.get_logger().info('service not available, waiting again...')
        
    def update(self, info):
        self.req_info = SetParametersAtomically.Request()
        self.req_info.parameters= [i.to_parameter_msg() for i in info]
        self.future_info = self.cli_info.call_async(self.req_info)
        rclpy.spin_until_future_complete(self, self.future_info)
        return self.future_info.result()
            
def main(args=None):
    rclpy.init(args=args)
    haptic_client = HapticClient()

    params_list = [
        Parameter(name='enable', value = True),
    ]
    response = haptic_client.update(params_list)
    print(response)
    
    haptic_client.destroy_node()
    rclpy.shutdown()
    
if __name__ == '__main__':
    main()